@@ -241,7 +241,7 @@ class ezcBaseFileIsAbsoluteTest extends ezcTestCase
 
     public static function suite()
     {
-         return new PHPUnit_Framework_TestSuite( "ezcBaseFileIsAbsoluteTest" );
+         return new PHPUnit\Framework\TestSuite( "ezcBaseFileIsAbsoluteTest" );
     }
 }
 ?>
